"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFeature = void 0;
const react_1 = require("react");
const use_engine_context_1 = require("./use-engine-context");
/**
 * A hook to access the state of a feature.
 *
 * This hook takes an optional `callerId` as the second parameter. The `callerId` improves the reliability
 * of eventing data by allowing the Decision Engine to identify the calling React Component through
 * the session's duration, thereby limiting duplicate eventing. The Engine considers all calls with
 * the same `callerId` to be the same Component; when rendering multiple instances of the same Component,
 * it can be advantageous to pass a unique `callerId`, allowing the Engine to track each Component
 * individually.
 *
 * @param {string} humanReadableId the human readable identifier of the `Feature`
 * @param {string=} callerId an identifier of the rendering React Component
 *
 * @returns {Feature} the `Feature` corresponding to the passed `featureReadableId`. If no feature exists
 * with the passed `featureReadableId` then an `InactiveFeature` is returned.
 *
 * @example
 * export const ExampleComponent = () => {
 *   const [isMyFeatureEnabled, { myFeatureVariable }, metaData] = useFeature(
 *     'my-feature.H291fd',
 *     'ExampleComponent',
 *   );
 *   return <div>{isMyFeatureEnabled && <span>{myFeatureVariable}</span>}</div>;
 * };
 */
exports.useFeature = (featureReadableId, callerId) => {
    if (process.env.NODE_ENV !== 'production') {
        if (!featureReadableId) {
            throw new Error('You must pass a featureReadableId to useFeature');
        }
    }
    const engine = use_engine_context_1.useEngineContext('useFeature');
    const callerIdValue = react_1.useRef(callerId !== null && callerId !== void 0 ? callerId : Math.random().toString());
    return react_1.useMemo(() => {
        const { isEnabled, variables, metaData } = engine.getFeature(featureReadableId, callerIdValue.current);
        return [isEnabled, variables !== null && variables !== void 0 ? variables : {}, metaData];
    }, [engine, featureReadableId]);
};
//# sourceMappingURL=use-feature.js.map